@@ -1,12 +1,23 @@
 """Several line plots of predictions and truths."""
 
+from typing import List, Optional, Union
+
+import numpy as np
 import plotly.graph_objects as go
 from plotly.subplots import make_subplots
-import numpy as np
-from typing import Union, List
 
 
-def make_trace(x, y, truth: bool, show_legend: bool = True):
+def make_trace(
+    x,
+    y,
+    truth: bool,
+    show_legend: bool = True,
+    name: str = None,
+    mode: str = "lines+markers",
+    marker_size: Union[int, List[int]] = 10,
+    color: Union[str, List[str]] = None,
+    opacity: Optional[float] = None,
+):
     """
     Make a plotly trace data (x,y).
 
@@ -15,22 +26,33 @@ def make_trace(x, y, truth: bool, show_legend: bool = True):
         y: values of data
         truth: if y is the truth or predictions. The colour of the line changed depending on this
         show_legend: option to show the legend for this trace or not.
+        name: name of the trace
+        color: the size of the markers
+        marker_size: the size of the markers
+        mode: the mode for plotting,
+            see ref. https://plotly.com/python/reference/scatter/#scatter-mode
+        opacity: the opacity of the lines (and markers)
 
     Returns:plotly trace
 
     """
-    color = "Blue" if truth else "Red"
-    name = "truth" if truth else "predict"
+    if color is None:
+        color = "Blue" if truth else "Red"
+    if name is None:
+        name = "truth" if truth else "predict"
 
-    return go.Scatter(
+    trace = go.Scatter(
         x=x,
         y=y,
-        mode="lines+markers",
-        marker=dict(color=color, line=dict(color=color, width=2)),
+        mode=mode,
+        marker=dict(color=color, line=dict(color=color, width=2), size=marker_size),
         name=name,
         showlegend=show_legend,
+        opacity=opacity,
     )
 
+    return trace
+
 
 def plot_one_result(x, y, y_hat):
     """
@@ -68,7 +90,8 @@ def plot_batch_results(
         y: the truth values of pv yield, should be size [batch_size, forecast length]
         y_hat: the predicted values of pv yield, should be size [batch_size, forecast length]
         model_name: the name of the model
-        x_hat: the x values for the predictions (y_hat), note that if none is supplied then x is used instead
+        x_hat: the x values for the predictions (y_hat),
+            note that if none is supplied then x is used instead
 
     Returns: a plotly figure
     """
@@ -80,16 +103,19 @@ def plot_batch_results(
 
     subplot_titles = [str(i) for i in range(batchsize)]
 
-    fig = make_subplots(rows=N,
-                        cols=N,
-                        subplot_titles=subplot_titles,
-                        x_title=f"Batch Plot of PV Predict: {model_name}")
+    fig = make_subplots(
+        rows=N,
+        cols=N,
+        subplot_titles=subplot_titles,
+        x_title=f"Batch Plot of PV Predict: {model_name}",
+    )
 
     # move the x_title to the top
-    # Could perhaps do this in a neater way, just happens that the last annotation is the x_title object
-    fig.layout.annotations[-1]['y'] = 1
-    fig.layout.annotations[-1]['yshift'] = 30
-    fig.layout.annotations[-1]['yanchor'] = 'bottom'
+    # Could perhaps do this in a neater way,
+    # just happens that the last annotation is the x_title object
+    fig.layout.annotations[-1]["y"] = 1
+    fig.layout.annotations[-1]["yshift"] = 30
+    fig.layout.annotations[-1]["yanchor"] = "bottom"
 
     for i in range(0, batchsize):
 
